/*********************************************
 * OPL 12.4 Model
 * Author: mwatson
 * Creation Date: Nov 12, 2012 at 10:52:23 AM
 * 
 * This model is meant to replicate the model 
 * on pages 87-89 of Supply Chain Network Design
 * This model adds capacity in a simple way:  each unit of demand is 1 unit of capacity
 *********************************************/


{string} Warehouses =...;  //this is I in the book and called a facility
{string} Customers =...;  // this is J in the book
int MaxWarehousesP =...;  // this is P in the book on page 49
float Demand[Customers] =...;  // this is d in the book
float Distance[Warehouses][Customers]=...;  // this is dist in the book
float Capacity[Warehouses]=...;  // this is the capacity available.  This is the only new line
dvar boolean OpenVar[Warehouses];  // this is X in the book
dvar boolean AssignVar[Warehouses][Customers];  //this is Y in the book
 
 minimize
  sum(w in Warehouses, c in Customers)
    Distance[w][c]*Demand[c]*AssignVar[w][c];
    
subject to{

  forall ( c in Customers )
    ctEachCustomersDemandMustBeMet:
    	sum( w in Warehouses )
    	  AssignVar[w][c]==1;	
  
    ctOnlyUse_P_Warehouses:
  	sum(w in Warehouses)
  	  OpenVar[w]==MaxWarehousesP;
  
    forall (w in Warehouses, c in Customers)
    ctCannotAssignCustomertoWH_UnlessItIsOpen:
      AssignVar[w][c] <= OpenVar[w];
    
    forall (w in Warehouses)
    ctCapacityConstraints:
      sum(c in Customers)
        Demand[c]*AssignVar[w][c]<= Capacity[w]*OpenVar[w] ;
}